@@ -47,7 +47,9 @@ def argument(*args, **kwargs):
 
 def format_taskgraph_labels(taskgraph):
     return "\n".join(
-        taskgraph.tasks[index].label for index in taskgraph.graph.visit_postorder()
+        sorted(
+            taskgraph.tasks[index].label for index in taskgraph.graph.visit_postorder()
+        )
     )
 
 
@@ -343,7 +345,7 @@ def show_taskgraph(options):
         logging.root.setLevel(logging.DEBUG)
 
     repo = None
-    cur_ref = None
+    cur_rev = None
     diffdir = None
     output_file = options["output_file"]
 
@@ -361,16 +363,16 @@ def show_taskgraph(options):
         # as best we can after we're done. In all known cases, using
         # branch or bookmark (which are both available on the VCS object)
         # as `branch` is preferable to a specific revision.
-        cur_ref = repo.branch or repo.head_ref[:12]
+        cur_rev = repo.branch or repo.head_rev[:12]
 
         diffdir = tempfile.mkdtemp()
         atexit.register(
             shutil.rmtree, diffdir
         )  # make sure the directory gets cleaned up
         options["output_file"] = os.path.join(
-            diffdir, f"{options['graph_attr']}_{cur_ref}"
+            diffdir, f"{options['graph_attr']}_{cur_rev}"
         )
-        print(f"Generating {options['graph_attr']} @ {cur_ref}", file=sys.stderr)
+        print(f"Generating {options['graph_attr']} @ {cur_rev}", file=sys.stderr)
 
     parameters: List[Any[str, Parameters]] = options.pop("parameters")
     if not parameters:
@@ -418,33 +420,33 @@ def show_taskgraph(options):
                 del sys.modules[mod]
 
         if options["diff"] == "default":
-            base_ref = repo.base_ref
+            base_rev = repo.base_rev
         else:
-            base_ref = options["diff"]
+            base_rev = options["diff"]
 
         try:
-            repo.update(base_ref)
-            base_ref = repo.head_ref[:12]
+            repo.update(base_rev)
+            base_rev = repo.head_rev[:12]
             options["output_file"] = os.path.join(
-                diffdir, f"{options['graph_attr']}_{base_ref}"
+                diffdir, f"{options['graph_attr']}_{base_rev}"
             )
-            print(f"Generating {options['graph_attr']} @ {base_ref}", file=sys.stderr)
+            print(f"Generating {options['graph_attr']} @ {base_rev}", file=sys.stderr)
             generate_taskgraph(options, parameters, logdir)
         finally:
-            repo.update(cur_ref)
+            repo.update(cur_rev)
 
         # Generate diff(s)
         diffcmd = [
             "diff",
             "-U20",
             "--report-identical-files",
-            f"--label={options['graph_attr']}@{base_ref}",
-            f"--label={options['graph_attr']}@{cur_ref}",
+            f"--label={options['graph_attr']}@{base_rev}",
+            f"--label={options['graph_attr']}@{cur_rev}",
         ]
 
         for spec in parameters:
-            base_path = os.path.join(diffdir, f"{options['graph_attr']}_{base_ref}")
-            cur_path = os.path.join(diffdir, f"{options['graph_attr']}_{cur_ref}")
+            base_path = os.path.join(diffdir, f"{options['graph_attr']}_{base_rev}")
+            cur_path = os.path.join(diffdir, f"{options['graph_attr']}_{cur_rev}")
 
             params_name = None
             if len(parameters) > 1:
@@ -593,6 +595,15 @@ def image_digest(args):
     help='Type of repository, either "hg" or "git"',
 )
 @argument("--base-repository", required=True, help='URL for "base" repository to clone')
+@argument(
+    "--base-ref", default="", help='Reference of the revision in the "base" repository'
+)
+@argument(
+    "--base-rev",
+    default="",
+    help="Taskgraph decides what to do based on the revision range between "
+    "`--base-rev` and `--head-rev`. Value is determined automatically if not provided",
+)
 @argument(
     "--head-repository",
     required=True,
@@ -717,6 +728,82 @@ def test_action_callback(options):
         sys.exit(1)
 
 
+@command(
+    "init", description="Initialize a new Taskgraph setup in a new or existing project."
+)
+@argument(
+    "-f",
+    "--force",
+    action="store_true",
+    default=False,
+    help="Bypass safety checks.",
+)
+@argument(
+    "--prompt",
+    dest="no_input",
+    action="store_false",
+    default=True,
+    help="Prompt for input rather than using default values (advanced).",
+)
+@argument(
+    "--template",
+    default="gh:taskcluster/taskgraph",
+    help=argparse.SUPPRESS,  # used for testing
+)
+def init_taskgraph(options):
+    from cookiecutter.main import cookiecutter
+
+    import taskgraph
+    from taskgraph.util.vcs import get_repository
+
+    repo = get_repository(os.getcwd())
+    root = Path(repo.path)
+
+    # Clean up existing installations if necessary.
+    tc_yml = root.joinpath(".taskcluster.yml")
+    if tc_yml.is_file():
+        if not options["force"]:
+            proceed = input(
+                "A Taskcluster setup already exists in this repository, "
+                "would you like to overwrite it? [y/N]: "
+            ).lower()
+            while proceed not in ("y", "yes", "n", "no"):
+                proceed = input(f"Invalid option '{proceed}'! Try again: ")
+
+            if proceed[0] == "n":
+                sys.exit(1)
+
+        tc_yml.unlink()
+        tg_dir = root.joinpath("taskcluster")
+        if tg_dir.is_dir():
+            shutil.rmtree(tg_dir)
+
+    # Populate some defaults from the current repository.
+    context = {"project_name": root.name}
+
+    repo_url = repo.get_url()
+    if repo.tool == "git" and "github.com" in repo_url:
+        context["repo_host"] = "github"
+    elif repo.tool == "hg" and "hg.mozilla.org" in repo_url:
+        context["repo_host"] = "hgmo"
+    else:
+        raise RuntimeError(
+            "Repository not supported! Taskgraph currently only "
+            "supports repositories hosted on Github or hg.mozilla.org."
+        )
+
+    # Generate the project.
+    cookiecutter(
+        options["template"],
+        checkout=taskgraph.__version__,
+        directory="template",
+        extra_context=context,
+        no_input=options["no_input"],
+        output_dir=root.parent,
+        overwrite_if_exists=True,
+    )
+
+
 def create_parser():
     parser = argparse.ArgumentParser(description="Interact with taskgraph")
     subparsers = parser.add_subparsers()
