@@ -7,7 +7,7 @@ import os
 
 import pytest
 from requests import Session
-from requests.exceptions import HTTPError
+from requests.exceptions import HTTPError, RetryError
 from requests.packages.urllib3.util.retry import Retry
 from responses import matchers
 
@@ -41,7 +41,6 @@ def proxy_root_url(monkeypatch, mock_environ):
 
 
 def test_get_root_url(monkeypatch):
-
     tc.get_root_url.clear()
     assert tc.get_root_url(False) == tc.PRODUCTION_TASKCLUSTER_ROOT_URL
 
@@ -194,7 +193,7 @@ def test_find_task_id(responses, root_url):
         f"{root_url}/api/index/v1/task/{index}",
         status=500,
     )
-    with pytest.raises(HTTPError):
+    with pytest.raises(RetryError):
         tc.find_task_id(index)
 
 
